@@ -473,7 +473,9 @@ make_iso (const char *filename, const char *label)
 	struct statfs statfs_buf;
 	GtkWidget *dialog;
 
-	tempdir = g_strdup_printf ("/tmp/iso-%s.XXXXXX", g_get_user_name ());
+	dirname = g_strdup_printf ("iso-%s.XXXXXX", g_get_user_name ());
+	tempdir = g_build_filename (g_get_tmp_dir (), dirname, NULL);
+	g_free (dirname);
 	state.tmpdir = mkdtemp (tempdir);
 
 	mkisofs_output.result = RESULT_ERROR;
