@@ -240,7 +240,7 @@ burn_cd (CDDrive *rec, const char *label, gboolean eject_cd, int speed, gboolean
 			return RESULT_CANCEL;
 		}
 	} else {
-		filename = g_build_filename ("/tmp", "image.iso.XXXXXX", NULL);
+		filename = g_build_filename (g_get_tmp_dir (), "image.iso.XXXXXX", NULL);
 		fd = mkstemp(filename);
 		close (fd);
 	}
